import path from 'node:path';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}

var getByteSize = function getByteSize(content) {
  if (typeof content === 'string') {
    return Buffer.from(content).length;
  }
  return (content == null ? void 0 : content.length) || 0;
};
var bundleToWebpackStats = function bundleToWebpackStats(bundle, customOptions) {
  var options = _extends({
    moduleOriginalSize: false
  }, customOptions);
  var items = Object.values(bundle);
  var assets = [];
  var chunks = [];
  var moduleByFileName = {};
  items.forEach(function (item) {
    if (item.type === 'chunk') {
      assets.push({
        name: item.fileName,
        size: getByteSize(item.code)
      });
      var chunkId = item.name;
      chunks.push({
        id: chunkId,
        entry: item.isEntry,
        initial: !item.isDynamicEntry,
        files: [item.fileName],
        names: [item.name]
      });
      Object.entries(item.modules).forEach(function (_ref) {
        var modulePath = _ref[0],
          moduleInfo = _ref[1];
        var relativeModulePath = path.relative(process.cwd(), modulePath.replace("\0", ''));
        var moduleEntry = moduleByFileName[relativeModulePath];
        if (moduleEntry) {
          moduleEntry.chunks.push(chunkId);
        } else {
          moduleByFileName[relativeModulePath] = {
            name: relativeModulePath,
            size: options.moduleOriginalSize ? moduleInfo.originalLength : moduleInfo.renderedLength,
            chunks: [chunkId]
          };
        }
      });
    } else if (item.type === 'asset') {
      assets.push({
        name: item.fileName,
        size: getByteSize(item.source)
      });
    }
  });
  var output = {
    assets: assets,
    chunks: chunks,
    modules: Object.values(moduleByFileName)
  };
  return output;
};

var NAME = 'webpackStats';
var webpackStats = function webpackStats(options) {
  if (options === void 0) {
    options = {};
  }
  return {
    name: NAME,
    generateBundle: function generateBundle(_, bundle) {
      var _options;
      var output = bundleToWebpackStats(bundle, options);
      this.emitFile({
        type: 'asset',
        fileName: ((_options = options) == null ? void 0 : _options.fileName) || 'webpack-stats.json',
        source: JSON.stringify(output)
      });
    }
  };
};

export { webpackStats };
//# sourceMappingURL=rollup-plugin-webpack-stats.esm.js.map
